@@ -14,6 +14,10 @@
 #include <hwloc.h>
 #include <hwloc/cpuset.h>
 #include <private/debug.h>
+#include <sys/types.h>
+#ifdef HAVE_STDINT_H
+#include <stdint.h>
+#endif
 
 #include <string.h>
 
@@ -108,7 +112,7 @@ struct hwloc_topology {
 
 extern void hwloc_setup_pu_level(struct hwloc_topology *topology, unsigned nb_pus);
 extern void hwloc_setup_misc_level_from_distances(struct hwloc_topology *topology, unsigned nbobjs, struct hwloc_obj **objs, unsigned *_distances/*[nbnobjs][nbobjs]*/);
-extern int hwloc_get_sysctlbyname(const char *name, int *n);
+extern int hwloc_get_sysctlbyname(const char *name, int64_t *n);
 extern int hwloc_get_sysctl(int name[], unsigned namelen, int *n);
 extern unsigned hwloc_fallback_nbprocessors(struct hwloc_topology *topology);
 
